<?php
/**
 * XButtonColumn class file.
 *
 * @author rootbear
 * @license http://www.yiiframework.com/license/
 *
 * version 1.0.1 April 19, 2012
 * 
 * to-do: more customized buttons?
 * 
 */

Yii::import('zii.widgets.grid.CButtonColumn');

/**
 * XButtonColumn added extra button(s) - [yesno].
 *
 */
class XButtonColumn extends CButtonColumn
{
	
	/**
	 * Properties mimic {delete} button in CButtonColumn.
	 */
	public $yesnoButtonLabel;
	public $yesnoButtonImageUrl;

	public $yesnoAction = 'yesno';
	public $yesnoButtonUrl=
		'Yii::app()->controller->createUrl("{yesno}",array("id"=>$data->primaryKey))';
	
	public $yesnoButtonOptions=array('class'=>'update');
	public $yesnoConfirmation;
	public $afterYesno;

	private $_baseExtImageUrl;
	
	/**
	 * Initializes the column.
	 */
	public function init()
	{
		$this->yesnoButtonUrl=str_replace("{yesno}", $this->yesnoAction, $this->yesnoButtonUrl);

		$image_path = dirname(__FILE__) . '/XButtonColumn/assets/images';
		$this->_baseExtImageUrl = Yii::app()->assetManager->publish( $image_path );

		$this->initExtraButtons();
		return parent::init();
	}

	/**
	 * Initializes the extra button(s) (yesno).
	 */
	protected function initExtraButtons()
	{
		if($this->yesnoButtonLabel===null)
			$this->yesnoButtonLabel=Yii::t('zii','YesNo');
		if($this->yesnoButtonImageUrl===null)
			$this->yesnoButtonImageUrl=$this->_baseExtImageUrl.'/flag.png';
		if($this->yesnoConfirmation===null)
			$this->yesnoConfirmation=Yii::t('zii','Are you sure you want to update [yes/no] this item?');

		foreach(array('yesno') as $id)
		{
			$button=array(
				'label'=>$this->{$id.'ButtonLabel'},
				'url'=>$this->{$id.'ButtonUrl'},
				'imageUrl'=>$this->{$id.'ButtonImageUrl'},
				'options'=>$this->{$id.'ButtonOptions'},
			);
			if(isset($this->buttons[$id]))
				$this->buttons[$id]=array_merge($button,$this->buttons[$id]);
			else
				$this->buttons[$id]=$button;
		}

		if(!isset($this->buttons['yesno']['click']))
		{
			if(is_string($this->yesnoConfirmation))
				$confirmation="if(!confirm(".CJavaScript::encode($this->yesnoConfirmation).")) return false;";
			else
				$confirmation='';

			if(Yii::app()->request->enableCsrfValidation)
			{
				$csrfTokenName = Yii::app()->request->csrfTokenName;
				$csrfToken = Yii::app()->request->csrfToken;
				$csrf = "\n\t\tdata:{ '$csrfTokenName':'$csrfToken' },";
			}
			else
				$csrf = '';

			if($this->afterYesno===null)
				$this->afterYesno='function(){}';

			$this->buttons['yesno']['click']=<<<EOD
function() {
	$confirmation
	var th=this;
	var afterYesno=$this->afterYesno;
	$.fn.yiiGridView.update('{$this->grid->id}', {
		type:'POST',
		debug:'TEST',
		url:$(this).attr('href'),$csrf
		success:function(data) {
			$.fn.yiiGridView.update('{$this->grid->id}');
			afterYesno(th,true,data);
		},
		error:function(XHR) {
			return afterYesno(th,false,XHR);
		}
	});
	return false;
}
EOD;
		}
	}

}